# This file is the entrypoint when you call [python -m MYPACKAGE]
#  You can import a function here and call it like
from .cli import app
app()
